contains the ArtificePeer struct
Structs
- Artifice
Peer - this is a peer that represents a (theoretically) remote computer, this struct provides an attempt to verify the peer by holding a text string that only this particular host, and one host have access to this is done in conjunction with public key authentication, as well as remote_user auth on an already encrypted channel so only those with permission can exercise their permissions side noote permissions and peers operate on white list rather then blacklist for the sake of safety.
- Layer3
Socket Addr - a serde serializable representation of std::net::SocketAddr
- Layer3
Socket Iter - this module is only supported on std, not tokio becuase it seems whoever implemented the tokio::net::ToSocketAddrs, was stingy, and made the trait a wrapper around a private trait a future implementation might use a std network stream, to construct the tokio equvilent
- Remote
Peer - used as a precursor to artifice peer, principly it is used to store information about a given peer that is intended to be publicly available information
Enums
- Layer3
Addr - representation of an IpAddr that can be saved to a file, the purpose of this being the ability to connect to stable global peers even after the cnnection has been closed for a time
Traits
- Peer
List - used in ConnectionRequests verify method, anything that implements this trait is assumed to be a list of peers that are allowed to connect to this device