pub enum Layer3Addr {
V4([u8; 4]),
V6([u16; 8]),
}Expand description
representation of an IpAddr that can be saved to a file, the purpose of this being the ability to connect to stable global peers even after the cnnection has been closed for a time
Variants
Implementations