Struct StreamHeader

pub struct StreamHeader { /* private fields */ }
used to ensure man in the middle attack doesn’t occure, but used in place of the Header struct because it is much smaller

Implementations

Source

impl StreamHeader

pub fn new(global_hash: &str, peer_hash: &str, packet_len: usize) -> Self

pub fn with_key( global_hash: &str, peer_hash: &str, aes_key: Vec<u8>, packet_len: usize, ) -> Self

pub fn set_packet_type(&mut self, packet_type: PacketType)

pub fn packet_type(&self) -> PacketType

pub fn global_peer_hash(&self) -> &str

pub fn peer_hash(&self) -> &str

pub fn key(&self) -> &[u8]

pub fn packet_len(&self) -> usize

pub fn data_len(&self) -> usize

pub fn set_packet_len(&mut self, packet_len: usize)

pub fn remander(&self) -> u8

remander is calculated by 128 - (packet_len % 128) to break into encryptable blocks for async for sync calculated based on 16 - (packet_len % 128)

pub fn set_remander(&mut self, remander: u8)

pub fn to_raw(&self) -> Vec<u8>

used in place of serde_json::to_string(), because serde_json generates un-needed data

pub fn to_raw_padded(&self) -> Vec<u8>

pub fn from_raw_padded(data: &[u8]) -> Result<Self, NetworkError>

pub fn from_raw(data: &[u8]) -> Result<Self, NetworkError>

convert 125 bytes (length of data) to StreamHeader